<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */


add_action( 'cmb2_init', 'niobe_metaboxes_default' );
function niobe_metaboxes_default() {

	// Start with an underscore to hide fields from custom fields list
	$prefix = 'niobe_met_';


	/* Page Settings ***************************************************************************/
	/* ************************************************************************************/
	$page_settings = new_cmb2_box( array(
		'id'           => 'page_heading_settings',
		'title'        => esc_html__( 'Show Page Heading', 'ova-niobe' ),
		'object_types' => array( 'page' ), // Post type
		'context'      => 'normal',
		'priority'     => 'high',
		'show_names'   => true,

	) );

	// Display title of page
	$page_settings->add_field( array(
		'name'             => esc_html__( 'Show title of page', 'ova-niobe' ),
		'desc'             => esc_html__( 'Allow display title of page', 'ova-niobe' ),
		'id'               => $prefix . 'page_heading',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'yes' => esc_html__( 'Yes', 'ova-niobe' ),
			'no'  => esc_html__( 'No', 'ova-niobe' )
		),
		'default'          => 'yes',

	) );


	/* Post Settings *********************************************************************************/
	/* *******************************************************************************/
	$post_settings = new_cmb2_box( array(
		'id'           => 'post_video',
		'title'        => esc_html__( 'Post Settings', 'ova-niobe' ),
		'object_types' => array( 'post' ), // Post type
		'context'      => 'normal',
		'priority'     => 'high',
		'show_names'   => true, // Show field names on the left
	) );

	// Video or Audio
	$post_settings->add_field( array(
		'name' => esc_html__( 'Link audio or video', 'ova-niobe' ),
		'desc' => esc_html__( 'Insert link audio or video use for video/audio post-format', 'ova-niobe' ),
		'id'   => $prefix . 'embed_media',
		'type' => 'oembed',
	) );


	// Gallery image
	$post_settings->add_field( array(
		'name' => esc_html__( 'Gallery image', 'ova-niobe' ),
		'desc' => esc_html__( 'image in gallery post format', 'ova-niobe' ),
		'id'   => $prefix . 'file_list',
		'type' => 'file_list',
	) );


	/* General Settings ***************************************************************/
	/* ********************************************************************************/
	$general_settings = new_cmb2_box( array(
		'id'           => 'layout_settings',
		'title'        => esc_html__( 'General Settings', 'ova-niobe' ),
		'object_types' => array( 'page', 'post', 'treatments_price' ), // Post type
		'context'      => 'normal',
		'priority'     => 'high',
		'show_names'   => true, // Show field names on the left
	) );


	$general_settings->add_field( array(
		'name'       => esc_html__( 'Background Menu when scroll', 'ova-niobe' ),
		'id'         => $prefix . 'location_theme',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'primary' => esc_html__( 'Primary Menu', 'ova-niobe' ),
			'scroll'   => esc_html__('Scroll Menu', 'ova-niobe' ),
		),
		'default' => 'primary',

	) );



	$general_settings->add_field( array(
		'name'             => esc_html__( 'Header Version', 'ova-niobe' ),
		'id'               => $prefix . 'header_version',
		'description'      => esc_html__( 'This value will override value in customizer', 'ova-niobe' ),
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => niobe_load_header_metabox(),
		'default'          => 'global'

	) );
	$general_settings->add_field( array(
		'name'       => esc_html__( 'Background Menu when scroll', 'ova-niobe' ),
		'id'         => $prefix . 'bg_menu_scroll',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'dark' => esc_html__( 'Dark', 'ova-niobe' ),
			'white'   => esc_html__('White', 'ova-niobe' ),
		),
		'default' => 'dark',

	) );


	$general_settings->add_field( array(
		'name'             => esc_html__( 'Footer Version', 'ova-niobe' ),
		'id'               => $prefix . 'footer_version',
		'description'      => esc_html__( 'This value will override value in customizer', 'ova-niobe' ),
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => niobe_load_footer_metabox(),
		'default'          => 'global'

	) );

	$general_settings->add_field( array(
		'name'             => esc_html__( 'Main Layout', 'ova-niobe' ),
		'desc'             => esc_html__( 'This value will override value in theme customizer', 'ova-niobe' ),
		'id'               => $prefix . 'main_layout',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'global'        => esc_html__( 'Global in customizer', 'ova-niobe' ),
			'right_sidebar' => esc_html__( 'Right Sidebar', 'ova-niobe' ),
			'left_sidebar'  => esc_html__( 'Left Sidebar', 'ova-niobe' ),
			'no_sidebar'    => esc_html__( 'No Sidebar', 'ova-niobe' )
		),
		'default'          => 'global',

	) );


	$general_settings->add_field( array(
		'name'             => esc_html__( 'Width of site', 'ova-niobe' ),
		'desc'             => esc_html__( 'This value will override value in theme customizer', 'ova-niobe' ),
		'id'               => $prefix . 'width_site',
		'type'             => 'select',
		'show_option_none' => false,
		'options'          => array(
			'global' => esc_html__( 'Global in customizer', 'ova-niobe' ),
			'wide'   => esc_html__( 'Wide', 'ova-niobe' ),
			'boxed'  => esc_html__( 'Boxed', 'ova-niobe' ),
		),
		'default'          => 'global',

	) );


	/* treatment Settings *********************************************************************************/
	/* *******************************************************************************/
	$treatmentsetting = new_cmb2_box( array(
		'id'           => 'treatment_price',
		'title'        => esc_html__( 'Treatments attribute', 'ova-niobe' ),
		'object_types' => array( 'treatments_price' ), // Post type
		'context'      => 'normal',
		'priority'     => 'high',
		'show_names'   => true, // Show field names on the left
	) );

	$treatmentsetting->add_field( array(
		'name'    => esc_html__( 'Price', 'ova-niobe' ),
		'id'      => $prefix . 'treatment_price',
		'default' => 0,
		'type'    => 'text_small',
	) );



	$treatmentsetting->add_field( array(
		'name'    => esc_html__( 'Order', 'ova-niobe' ),
		'id'      => $prefix . 'treatment_price_order',
		'default' => 0,
		'type'    => 'text_small',
	) );

	/* faq Settings *********************************************************************************/
	/* *******************************************************************************/
	$faqsetting = new_cmb2_box( array(
		'id'           => 'faq',
		'title'        => esc_html__( 'Order', 'ova-niobe' ),
		'object_types' => array( 'faq' ), // Post type
		'context'      => 'normal',
		'priority'     => 'high',
		'show_names'   => false,
	) );

	$faqsetting->add_field( array(
		'name'    => esc_html__( 'Order', 'ova-niobe' ),
		'id'      => $prefix . 'faq_order',
		'default' => 0,
		'type'    => 'text_small',
	) );


}

